@@ -115,7 +115,9 @@ static GtkActionEntry gnc_plugin_actions [] =
         G_CALLBACK(gnc_plugin_ab_cmd_issue_transaction)
     },
     {
-        "ABIssueSepaTransAction", NULL, N_("_Issue SEPA Transaction..."), NULL,
+        "ABIssueSepaTransAction", NULL,
+		/* Translators: https://en.wikipedia.org/wiki/Single_Euro_Payments_Area */
+		N_("_Issue SEPA Transaction..."), NULL,
         N_("Issue a new international European (SEPA) transaction online through Online Banking"),
         G_CALLBACK(gnc_plugin_ab_cmd_issue_sepatransaction)
     },
@@ -137,7 +139,10 @@ static GtkActionEntry gnc_plugin_actions [] =
 
     /* File -> Import menu item */
     {
-        "Mt940ImportAction", "go-previous", N_("Import _MT940"), NULL,
+        "Mt940ImportAction", "go-previous",
+		/* Translators: Message types MTxxxx are exchange formats used by the SWIFT network
+		   https://en.wikipedia.org/wiki/Society_for_Worldwide_Interbank_Financial_Telecommunication */
+		N_("Import _MT940"), NULL,
         N_("Import a MT940 file into GnuCash"),
         G_CALLBACK(gnc_plugin_ab_cmd_mt940_import)
     },
@@ -147,7 +152,10 @@ static GtkActionEntry gnc_plugin_actions [] =
         G_CALLBACK(gnc_plugin_ab_cmd_mt942_import)
     },
     {
-        "DtausImportAction", "go-previous", N_("Import _DTAUS"), NULL,
+        "DtausImportAction", "go-previous",
+		/* Translators: DTAUS is a traditional german exchange format.
+           https://de.wikipedia.org/wiki/Datentr%C3%A4geraustauschverfahren */
+		N_("Import _DTAUS"), NULL,
         N_("Import a DTAUS file into GnuCash"),
         G_CALLBACK(gnc_plugin_ab_cmd_dtaus_import)
     },
@@ -664,7 +672,8 @@ gnc_plugin_ab_cmd_mt940_import(GtkAction *action, GncMainWindowActionData *data)
     gchar *format = gnc_prefs_get_string(GNC_PREFS_GROUP_AQBANKING,
                                          GNC_PREF_FORMAT_SWIFT940);
     gnc_main_window = data->window;
-    gnc_file_aqbanking_import("swift", format ? format : "swift-mt940", FALSE);
+    gnc_file_aqbanking_import (GTK_WINDOW (gnc_main_window),
+                               "swift", format ? format : "swift-mt940", FALSE);
     g_free(format);
 }
 
@@ -674,7 +683,8 @@ gnc_plugin_ab_cmd_mt942_import(GtkAction *action, GncMainWindowActionData *data)
     gchar *format = gnc_prefs_get_string(GNC_PREFS_GROUP_AQBANKING,
                                          GNC_PREF_FORMAT_SWIFT942);
     gnc_main_window = data->window;
-    gnc_file_aqbanking_import("swift", format ? format : "swift-mt942", FALSE);
+    gnc_file_aqbanking_import (GTK_WINDOW (gnc_main_window),
+                               "swift", format ? format : "swift-mt942", FALSE);
     g_free(format);
 }
 
@@ -684,7 +694,8 @@ gnc_plugin_ab_cmd_dtaus_import(GtkAction *action, GncMainWindowActionData *data)
     gchar *format = gnc_prefs_get_string(GNC_PREFS_GROUP_AQBANKING,
                                          GNC_PREF_FORMAT_DTAUS);
     gnc_main_window = data->window;
-    gnc_file_aqbanking_import("dtaus", format ? format : "default", FALSE);
+    gnc_file_aqbanking_import (GTK_WINDOW (gnc_main_window),
+                               "dtaus", format ? format : "default", FALSE);
     g_free(format);
 }
 
@@ -695,7 +706,8 @@ gnc_plugin_ab_cmd_dtaus_importsend(GtkAction *action,
     gchar *format = gnc_prefs_get_string(GNC_PREFS_GROUP_AQBANKING,
                                          GNC_PREF_FORMAT_DTAUS);
     gnc_main_window = data->window;
-    gnc_file_aqbanking_import("dtaus", format ? format : "default", TRUE);
+    gnc_file_aqbanking_import (GTK_WINDOW (gnc_main_window),
+                               "dtaus", format ? format : "default", TRUE);
     g_free(format);
 }
 
